Module io

Module io 

Functions

create_file
Create a new doing file at path with a single default section.
read_file
Read and parse a doing file from path into a Document.
write_file
Serialize and atomically write a Document to path.