write_file

Function write_file 

pub fn write_file(doc: &Document, path: &Path) -> Result<()>
Serialize and atomically write a Document to path.

Writes to a temporary file in the same directory first, then renames into place to prevent corruption from interrupted writes. Callers are responsible for sorting entries before calling this function.