serialize

Function serialize 

pub fn serialize(doc: &Document) -> String
Serialize a Document into the doing file format string.

Deduplicates entries by ID and strips any ANSI color codes from the output. Callers are responsible for sorting entries before calling this function.